# crack https://github.com/Eddie2111/ProblemSolvers/commit/a109ac434465359db62f41d9c7dddc8c2f37924e
# model = Model("Vosk/vosk-model-en-in-0.5") 


from vosk import Model, KaldiRecognizer
import pyaudio
import os
import sys
import platform
import subprocess
from glob import glob
import urllib.request
import zipfile

MODEL_PTH = os.path.join(os.path.dirname(__file__), "Vosk")
MODEL_URL = "https://alphacephei.com/vosk/models/vosk-model-en-us-daanzu-20200905-lgraph.zip"
OSYS = platform.system()

if not os.path.exists(MODEL_PTH):
    os.mkdir(MODEL_PTH)
    print("Created Model Folder")

class Recognize(object):

    def __init__(self):
        ZIP_PTH = os.path.join(MODEL_PTH, "vosk-model-en-us-daanzu-20200905-lgraph.zip")
        resp = urllib.request.urlretrieve(MODEL_URL, ZIP_PTH)
        with zipfile.ZipFile(ZIP_PTH, 'r') as zip_ref:
            zip_ref.extractall(MODEL_PTH)

        self.model = Model(os.path.join(MODEL_PTH, "vosk-model-en-us-daanzu-20200905-lgraph"))
        self.recognizer = KaldiRecognizer(self.model,16000)

    def __str__(self):
        return """Class to initiate speech recognizer"""

    def model(self):
        return self.recognizer

    @classmethod
    def recognize(self, recognizer_model):
        mic = pyaudio.PyAudio()
        stream = mic.open(rate=16000, channels=1, format=pyaudio.paInt16,input=True, frames_per_buffer=8192)
        stream.start_stream()
        print('start speaking')

        while True:
            data = stream.read(4096)
            if len(data) == 0:
                break
            if recognizer_model.AcceptWaveform(data):
                x = recognizer_model.Result()
                print(x)
                break
        return x



from setuptools import setup, find_packages
import os
import sys
import platform
import subprocess
from setuptools.command.install import install
from glob import glob

class CustomInstallCommand(install):
    def run(self):
        print("Running custom install command for PyAudio")
        # Your custom install code goes here
        install.run(self)
        
        operatingsystem = platform.system()

        if operatingsystem == "Linux":
            try:
                subprocess.call(["sudo apt-get update"], shell=True)
                subprocess.call(["sudo apt-get upgrade"], shell=True)
                subprocess.call(["sudo apt-get install portaudio19-dev"], shell=True)
                subprocess.call(["sudo pip install pyaudio"], shell=True)
            except:
                print(f"Installation failed on system {operatingsystem}")
                print(f"Kindly install PyAudio using Installation Journal")
        else:
            try:
                os.execv(sys.executable, ["python", "-m", "pip", "install", "pyaudio"])
            except:
                print(f"Installation failed on system {operatingsystem}")
                print(f"Kindly install PyAudio using pip install pyaudio")


with open("README.md", "rb") as fh:
    long_description = fh.read().decode("utf-8")

setup(
    name='grokspeechrec',
    version='0.0.1',
    license='MIT',
    author="GROKLEARNING",
    author_email='visalakshi2001@gmail.com',
    description = "TEST APP TMLC",
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages= ["grokspeechrec", "grokspeechrec.speechrec"],
    package_dir={'grokspeechrec': 'src'},
    py_modules=["grokspeechrec.speechrec.app"],
    url='https://github.com/visalakshi2001/grokspeechrec/',
    keywords='speech recognizer',
    setup_requires=['vosk'],
    install_requires=['vosk'],
    cmdclass={
        'install': CustomInstallCommand,
    },
    # data_files= glob("./src/speechrec/Vosk/**/*", recursive=True),
    # package_data= {'': glob("./src/speechrec/Vosk/**/**", recursive=True)},
)